A client for interacting with the FW API.
See the FWClientBuilder for more information on how to create a client.
See the FWClient documentation for more information on how to use the client.
Re-exports
pub use crate::middleware::FWOptions;
Modules
Structs
- FWClient
- A client for interacting with the FW API.
- FWClient
Builder - Builder for the
FWClient.